@@ -197,8 +197,6 @@ class WeixinPay(object):
             raise WeixinPayError("退款申请接口中，缺少必填参数total_fee");
         if "refund_fee" not in data:
             raise WeixinPayError("退款申请接口中，缺少必填参数refund_fee");
-        if "op_user_id" not in data:
-            raise WeixinPayError("退款申请接口中，缺少必填参数op_user_id");
 
         return self._fetch(url, data, True)
 
